@@ -1,25 +1,9 @@
 /*
   This file is part of Akregator.
 
-  Copyright (C) 2004 Sashmit Bhaduri <smt@vfemail.net>
+  SPDX-FileCopyrightText: 2004 Sashmit Bhaduri <smt@vfemail.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "akregator_plugin.h"
@@ -114,7 +98,7 @@ void AkregatorPlugin::addFeed()
 void AkregatorPlugin::readProperties(const KConfigGroup &config)
 {
     if (part()) {
-        Akregator::Part *myPart = static_cast<Akregator::Part *>(part());
+        auto *myPart = static_cast<Akregator::Part *>(part());
         myPart->readProperties(config);
     }
 }
@@ -122,7 +106,7 @@ void AkregatorPlugin::readProperties(const KConfigGroup &config)
 void AkregatorPlugin::saveProperties(KConfigGroup &config)
 {
     if (part()) {
-        Akregator::Part *myPart = static_cast<Akregator::Part *>(part());
+        auto *myPart = static_cast<Akregator::Part *>(part());
         myPart->saveProperties(config);
     }
 }
