@@ -1,22 +1,16 @@
 /***************************************************************************
-begin                : 2004/03/12
-copyright            : (C) Mark Kretschmann
-email                : markey@web.de
+    SPDX-FileCopyrightText: 2004 Mark Kretschmann <markey@web.de>
 ***************************************************************************/
 
 /***************************************************************************
  *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   SPDX-License-Identifier: GPL-2.0-or-later                             *
  *                                                                         *
  ***************************************************************************/
 
 #include "pluginmanager.h"
 #include "plugin.h"
 
-#include <vector>
 #include <QString>
 
 #include "akregator_debug.h"
@@ -87,7 +81,7 @@ PluginManager::createFromService(const KService::Ptr &service, QObject *parent)
                                                    " Error message: %2").arg(service->library(), loader.errorString());
         return nullptr;
     }
-    Plugin *const plugin = factory->create<Plugin>(parent);
+    auto *const plugin = factory->create<Plugin>(parent);
 
     //put plugin into store
     StoreItem item;
